@@ -58,7 +58,7 @@ def main(config):
             conf_sensors = config['sensors']['temp']
             sensors = [TempSensor.from_kind(**a) for a in conf_sensors]
             for sensor in sensors:
-                logger.info(f"loaded sensor: {sensor}")
+                logger.info(f"emitting data for {sensor}")
 
             with TempPublisher(broker, freq, loc, sensors) as publisher:
                 publisher.loop()
